/* This file has been prepared for Doxygen automatic documentation generation.*/
/*! \file *********************************************************************
 *
 * \brief  XMEGA Timer/Counter driver header file.
 *
 *      This file contains the function prototypes and enumerator definitions
 *      for various configuration parameters for the XMEGA Timer/Counter driver.
 *
 *      The driver is not intended for size and/or speed critical code, since
 *      most functions are just a few lines of code, and the function call
 *      overhead would decrease code performance. The driver is intended for
 *      rapid prototyping and documentation purposes for getting started with
 *      the XMEGA Timer/Counter module.
 *
 *      For size and/or speed critical code, it is recommended to copy the
 *      function contents directly into your application instead of making
 *      a function call.
 *
 * \par Application note:
 *      AVR1306: Using the XMEGA Timer/Counter
 *
 * \par Documentation
 *      For comprehensive code documentation, supported compilers, compiler
 *      settings and supported devices see readme.html
 *
 * \author
 *      Atmel Corporation: http://www.atmel.com \n
 *      Support email: avr@atmel.com
 *
 * $Revision: 1569 $
 * $Date: 2008-04-22 13:03:43 +0200 (ti, 22 apr 2008) $  \n
 *
 * Copyright (c) 2008, Atmel Corporation All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of ATMEL may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY AND
 * SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/
#ifndef TC_DRIVER_H
#define TC_DRIVER_H

#include "avr_compiler.h"

/* Definition of macros. */


/*! \brief Sets the timer period.
 *
 *  This macro sets a new timer period. The period buffer register is not
 *  used, so the new period will be valid immediately after the 16-bit write
 *  is finished.
 *
 *  \param _tc               Timer/Counter module instance.
 *  \param _period           New Timer/Counter period.
 */
#define TC_SetPeriod( _tc, _period ) ( (_tc)->PER = (_period) )


/*! \brief Manually set the count.
 *
 *  This macro writes a new value to the CNT[H:L] register.
 *  Note that the CNT[H:L] register is not double buffered, so it is recommended
 *  that the timer is not running when this macro is used.
 *
 *  \param _tc               Timer/Counter module instance.
 *  \param _count            New count value.
 */
#define TC_SetCount( _tc, _count ) ( (_tc)->CNT = (_count) )

/*! \brief Sets the timer period ( double buffered ).
 *
 *  This macro sets a new timer period. The period buffer register is used,
 *  so the new period will be valid after the next update condition.
 *
 *  \param _tc               Timer/Counter 0 or 1 module instance.
 *  \param _period           New Timer/Counter period.
 */
#define TC_SetPeriodBuffered( _tc, _period ) ( (_tc)->PERBUF = (_period) )


/*! \brief Test whether an overflow has occurred.
 *
 *  The return value of this macro indicates if an overflow has occurred.
 *
 *  \param  _tc Timer/Counter module instance.
 *
 *  \return Non-zero if overflow flag is set, zero otherwise.
 */
#define TC_GetOverflowFlag( _tc ) ( (_tc)->INTFLAGS & TC0_OVFIF_bm )

/*! \brief Clears the Timer/Counter overflow flag.
 *
 *   This macro clears the Timer/Counter overflow flag.
 *
 *  \param _tc  Timer/Counter module instance.
 */
#define TC_ClearOverflowFlag( _tc ) ( (_tc)->INTFLAGS = TC0_OVFIF_bm )



/* Prototyping of functions. Documentation can be found in source file. */

void TC0_ConfigClockSource( volatile TC0_t * tc, TC_CLKSEL_t clockSelection );

void TC0_SetOverflowIntLevel( volatile TC0_t * tc, TC_OVFINTLVL_t intLevel );
void TC0_Reset( volatile TC0_t * tc );


#endif
